@@ -5,7 +5,7 @@
 #include <pango/pango-context.h>
 
 enum {
-	PASTE_CONTENT		= 1 << 0, /* either CONTENT or AS_VALUES */
+	PASTE_CONTENTS		= 1 << 0, /* either CONTENTS or AS_VALUES */
 	PASTE_AS_VALUES		= 1 << 1, /*  can be applied, not both */
 	PASTE_FORMATS		= 1 << 2,
 	PASTE_COMMENTS		= 1 << 3,
@@ -35,38 +35,33 @@ enum {
 	/* Update the row height when pasting? (for large fonts, etc.) */
 	PASTE_UPDATE_ROW_HEIGHT = 1 << 14,
 
-	PASTE_EXPR_LOCAL_RELOCATE = 1 << 15
+	PASTE_EXPR_LOCAL_RELOCATE = 1 << 15,
+
+	/* Avoid flagging dependencies.  */
+	PASTE_NO_RECALC         = 1 << 16
 };
 
-#define PASTE_ALL_TYPES (PASTE_CONTENT | PASTE_FORMATS | PASTE_COMMENTS | PASTE_OBJECTS)
+#define PASTE_ALL_TYPES (PASTE_CONTENTS | PASTE_FORMATS | PASTE_COMMENTS | PASTE_OBJECTS)
 #define PASTE_DEFAULT   PASTE_ALL_TYPES
 #define PASTE_OPER_MASK (PASTE_OPER_ADD | PASTE_OPER_SUB | PASTE_OPER_MULT | PASTE_OPER_DIV)
 
-typedef enum {
-	CELL_COPY_TYPE_CELL,
-	CELL_COPY_TYPE_TEXT
-} CellCopyType;
-
 typedef struct {
-	int col_offset, row_offset; /* Position of the cell */
-	CellCopyType type;
-	union {
-		GnmCell *cell;
-		char *text;
-	} u;
-} CellCopy;
-
-typedef GSList CellCopyList;
+	GnmCellPos const  offset;	/* must be first element */
+	GnmValue *val;
+	GnmExprTop const *texpr;
+} GnmCellCopy;
 
 struct _GnmCellRegion {
 	Sheet		*origin_sheet; /* can be NULL */
 	GnmCellPos	 base;
 	int		 cols, rows;
-	CellCopyList	*content;
+	ColRowStateList *col_state, *row_state;
+	GHashTable	*cell_content;
 	GnmStyleList	*styles;
 	GSList		*merged;
 	GSList		*objects;
-	gboolean	 not_as_content;
+	gboolean	 not_as_contents;
+
 	unsigned	 ref_count;
 };
 
@@ -76,16 +71,29 @@ struct _GnmPasteTarget {
 	int         paste_flags;
 };
 
-GnmCellRegion *clipboard_copy_range   (Sheet *sheet, GnmRange const *r);
-gboolean       clipboard_paste_region (GnmCellRegion const *content,
-				       GnmPasteTarget const *pt,
-				       GnmCmdContext *cc);
-GnmPasteTarget*paste_target_init      (GnmPasteTarget *pt,
-				       Sheet *sheet, GnmRange const *r, int flags);
+GnmCellRegion  *clipboard_copy_range   (Sheet *sheet, GnmRange const *r);
+GnmCellRegion  *clipboard_copy_obj     (Sheet *sheet, GSList *objects);
+gboolean        clipboard_paste_region (GnmCellRegion const *cr,
+					GnmPasteTarget const *pt,
+					GOCmdContext *cc);
+GnmPasteTarget *paste_target_init      (GnmPasteTarget *pt,
+					Sheet *sheet, GnmRange const *r,
+					int flags);
+
+GnmCellRegion *cellregion_new	(Sheet *origin_sheet);
+void           cellregion_ref		(GnmCellRegion *cr);
+void           cellregion_unref		(GnmCellRegion *cr);
+GString	      *cellregion_to_string	(GnmCellRegion const *cr,
+					 gboolean only_visible,
+					 GODateConventions const *date_conv);
+int            cellregion_cmd_size	(GnmCellRegion const *cr);
+void	       cellregion_invalidate_sheet (GnmCellRegion *cr, Sheet *sheet);
+
+GnmCellCopy   *gnm_cell_copy_new (GnmCellRegion *cr,
+				  int col_offset, int row_offset);
+
+void clipboard_init (void);
+void clipboard_shutdown (void);
 
-GnmCellRegion *cellregion_new	 (Sheet *origin_sheet);
-void        cellregion_ref       (GnmCellRegion *content);
-void        cellregion_unref     (GnmCellRegion *content);
-char	   *cellregion_to_string (GnmCellRegion const *content, PangoContext *context);
 
 #endif /* GNUMERIC_CLIPBOARD_H */
