@@ -1,3 +1,4 @@
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /**
  * dialog-col-width.c:  Sets the magnification factor
  *
@@ -21,7 +22,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n-lib.h>
 #include <gnumeric.h>
 #include "dialogs.h"
 #include "help.h"
@@ -122,7 +123,7 @@ dialog_col_width_set_value (gnm_float value, ColWidthState *state)
 static void
 dialog_col_width_load_value (ColWidthState *state)
 {
-	GList *l;
+	GSList *l;
 	gnm_float value = 0.0;
 	state->orig_is_default = TRUE;
 	state->orig_some_default = FALSE;
@@ -190,7 +191,7 @@ cb_dialog_col_width_apply_clicked (G_GNUC_UNUSED GtkWidget *button,
 	gnm_float value = gtk_spin_button_get_value (state->spin);
 	double const scale =
 		state->sheet->last_zoom_factor_used *
-		application_display_dpi_get (FALSE) / 72.;
+		gnm_app_display_dpi_get (FALSE) / 72.;
 	int size_pixels = (int)(value * scale + 0.5);
 	gboolean use_default = gtk_toggle_button_get_active
 		(GTK_TOGGLE_BUTTON (state->default_check));
@@ -204,8 +205,7 @@ cb_dialog_col_width_apply_clicked (G_GNUC_UNUSED GtkWidget *button,
 			size_pixels = 0;
 
 		workbook_cmd_resize_selected_colrow (WORKBOOK_CONTROL (state->wbcg),
-						     TRUE, state->sheet,
-						     size_pixels);
+			state->sheet, TRUE, size_pixels);
 		dialog_col_width_load_value (state);
 	}
 
@@ -254,7 +254,7 @@ dialog_col_width (WorkbookControlGUI *wbcg, gboolean use_default)
 
 	if (gnumeric_dialog_raise_if_exists (wbcg, COL_WIDTH_DIALOG_KEY))
 		return;
-	gui = gnm_glade_xml_new (COMMAND_CONTEXT (wbcg),
+	gui = gnm_glade_xml_new (GO_CMD_CONTEXT (wbcg),
 		"col-width.glade", NULL, NULL);
 	if (gui == NULL)
 		return;
@@ -271,8 +271,7 @@ dialog_col_width (WorkbookControlGUI *wbcg, gboolean use_default)
 
 	state->spin  = GTK_SPIN_BUTTON (glade_xml_get_widget (state->gui, "spin"));
 	gtk_spin_button_get_adjustment (state->spin)->lower =
-		state->sheet->cols.default_style.margin_a +
-		state->sheet->cols.default_style.margin_b;
+		GNM_COL_MARGIN + GNM_COL_MARGIN;
 	g_signal_connect (G_OBJECT (state->spin),
 		"value-changed",
 		G_CALLBACK (cb_dialog_col_width_value_changed), state);
