@@ -1,3 +1,4 @@
+
 /* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * dialog-sheet-order.c: Dialog to change the order of sheets in the Gnumeric
@@ -54,6 +55,8 @@
 #include <string.h>
 #include <stdio.h>
 
+#define SHEET_ORDER_KEY          "sheet-order-dialog"
+
 typedef struct {
 	WorkbookControlGUI  *wbcg;
 
@@ -113,8 +116,13 @@ cb_name_edited (G_GNUC_UNUSED GtkCellRendererText *cell,
 
 	path = gtk_tree_path_new_from_string (path_string);
 
-	gtk_tree_model_get_iter (GTK_TREE_MODEL (state->model), &iter, path);
-	gtk_list_store_set (state->model, &iter, SHEET_NEW_NAME, new_text, -1);
+	if (gtk_tree_model_get_iter (GTK_TREE_MODEL (state->model), 
+				     &iter, path)) {
+		gtk_list_store_set (state->model, &iter, 
+				    SHEET_NEW_NAME, new_text, -1);
+	} else {
+		g_warning ("Did not get a valid iterator");
+	}
 
 	gtk_tree_path_free (path);
 }
@@ -166,6 +174,7 @@ cb_selection_changed (G_GNUC_UNUSED GtkTreeSelection *ignored,
 	GtkTreeIter  it, iter;
 	Sheet *sheet;
 	gboolean is_deleted;
+	gboolean has_iter;
 	GdkColor *fore, *back;
 	GtkTreeSelection *selection = gtk_tree_view_get_selection (state->sheet_list);
 
@@ -204,9 +213,8 @@ cb_selection_changed (G_GNUC_UNUSED GtkTreeSelection *ignored,
                               is_deleted ? GTK_STOCK_UNDELETE : GTK_STOCK_DELETE);
 	gtk_button_set_alignment (GTK_BUTTON (state->delete_btn), 0., .5);
 
-	gtk_tree_model_get_iter_first
-		(GTK_TREE_MODEL (state->model),
-		 &iter);
+	has_iter = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (state->model), &iter);
+	g_return_if_fail (has_iter);
 	gtk_widget_set_sensitive (state->up_btn,
 				  !gtk_tree_selection_iter_is_selected (selection, &iter));
 	it = iter;
@@ -232,15 +240,22 @@ cb_toggled_lock (G_GNUC_UNUSED GtkCellRendererToggle *cell,
 	GtkTreePath *path = gtk_tree_path_new_from_string (path_string);
 	gboolean value;
 
-	gtk_tree_model_get_iter (model, &iter, path);
-	gtk_tree_model_get (model, &iter, SHEET_LOCKED, &value, -1);
+	if (gtk_tree_model_get_iter (model, &iter, path)) {
+		gtk_tree_model_get (model, &iter, SHEET_LOCKED, &value, -1);
 
-	if (value) {
-		gtk_list_store_set (GTK_LIST_STORE (model), &iter, SHEET_LOCKED, FALSE,
-				   SHEET_LOCK_IMAGE, state->image_padlock_no, -1);
+		if (value) {
+			gtk_list_store_set 
+				(GTK_LIST_STORE (model), &iter, SHEET_LOCKED,
+				 FALSE, SHEET_LOCK_IMAGE, 
+				 state->image_padlock_no, -1);
+		} else {
+			gtk_list_store_set 
+				(GTK_LIST_STORE (model), &iter, SHEET_LOCKED,
+				 TRUE, SHEET_LOCK_IMAGE, 
+				 state->image_padlock, -1);
+		}
 	} else {
-		gtk_list_store_set (GTK_LIST_STORE (model), &iter, SHEET_LOCKED, TRUE,
-				   SHEET_LOCK_IMAGE, state->image_padlock, -1);
+		g_warning ("Did not get a valid iterator");
 	}
 	gtk_tree_path_free (path);
 }
@@ -255,12 +270,18 @@ cb_toggled_direction (G_GNUC_UNUSED GtkCellRendererToggle *cell,
 	GtkTreeIter iter;
 	gboolean value;
 
-	gtk_tree_model_get_iter (model, &iter, path);
-	gtk_tree_model_get (model, &iter, SHEET_DIRECTION, &value, -1);
-	gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-		SHEET_DIRECTION,	!value,
-		SHEET_DIRECTION_IMAGE,	value ? state->image_ltr : state->image_rtl,
-		-1);
+	if (gtk_tree_model_get_iter (model, &iter, path)) {
+		gtk_tree_model_get (model, &iter, SHEET_DIRECTION, &value, -1);
+		gtk_list_store_set 
+			(GTK_LIST_STORE (model), &iter,
+			 SHEET_DIRECTION,	!value,
+			 SHEET_DIRECTION_IMAGE,	
+			 value ? state->image_ltr : state->image_rtl,
+			 -1);
+	} else {
+		g_warning ("Did not get a valid iterator");
+	}
+
 	gtk_tree_path_free (path);
 }
 
@@ -275,20 +296,24 @@ cb_toggled_visible (G_GNUC_UNUSED GtkCellRendererToggle *cell,
 	GtkTreePath *path = gtk_tree_path_new_from_string (path_string);
 	gboolean value;
 
-	gtk_tree_model_get_iter (model, &iter, path);
-	gtk_tree_model_get (model, &iter, SHEET_VISIBLE, &value, -1);
-
-	if (value) {
-		gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-				    SHEET_VISIBLE, FALSE,
-				    SHEET_VISIBLE_IMAGE, NULL,
-				    -1);
-
+	if (gtk_tree_model_get_iter (model, &iter, path)) {
+		gtk_tree_model_get (model, &iter, SHEET_VISIBLE, &value, -1);
+		
+		if (value) {
+			gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+					    SHEET_VISIBLE, FALSE,
+					    SHEET_VISIBLE_IMAGE, NULL,
+					    -1);
+			
+		} else {
+			gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+					    SHEET_VISIBLE, TRUE,
+					    SHEET_VISIBLE_IMAGE, 
+					    state->image_visible,
+					    -1);
+		}
 	} else {
-		gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-				    SHEET_VISIBLE, TRUE,
-				    SHEET_VISIBLE_IMAGE, state->image_visible,
-				    -1);
+		g_warning ("Did not get a valid iterator");
 	}
 	gtk_tree_path_free (path);
 }
@@ -679,6 +704,7 @@ cb_ok_clicked (G_GNUC_UNUSED GtkWidget *ignore, SheetManager *state)
 {
 	WorkbookControl *wbc = WORKBOOK_CONTROL (state->wbcg);
 	Workbook *wb = wb_control_get_workbook (wbc);
+	Sheet *cur_sheet;
 	char *error;
 	gboolean changed;
 	WorkbookSheetState *old_state;
@@ -760,6 +786,11 @@ cb_ok_clicked (G_GNUC_UNUSED GtkWidget *ignore, SheetManager *state)
 		if (back) gdk_color_free (back);
 		n++;
 	}
+	
+	cur_sheet  = wb_view_cur_sheet (wb_control_view (wbc));
+	if (!cur_sheet || cur_sheet->index_in_wb == -1)
+		wb_view_sheet_focus (wb_control_view (wbc), 
+				     workbook_sheet_by_index (wb, 0));
 
 	cmd_reorganize_sheets (wbc, old_state, NULL);
 	gtk_widget_destroy (GTK_WIDGET (state->dialog));
@@ -778,6 +809,7 @@ cb_sheet_order_destroy (SheetManager *state)
 	wbcg_edit_detach_guru (state->wbcg);
 
 	g_object_unref (G_OBJECT (state->gui));
+	g_object_set_data (G_OBJECT (wb), SHEET_ORDER_KEY, NULL);
 	state->gui = NULL;
 
 	g_object_unref (state->image_padlock);
@@ -966,6 +998,18 @@ dialog_sheet_order (WorkbookControlGUI *wbcg)
         if (gui == NULL)
                 return;
 
+	wb = wb_control_get_workbook (WORKBOOK_CONTROL (wbcg));
+	if (g_object_get_data (G_OBJECT (wb), SHEET_ORDER_KEY)) {
+		GtkWidget *dialog = gtk_message_dialog_new 
+			(wbcg_toplevel (wbcg),
+			 GTK_DIALOG_DESTROY_WITH_PARENT,
+			 GTK_MESSAGE_WARNING,
+			 GTK_BUTTONS_CLOSE,
+			 _("Another view is already managing sheets"));
+		go_gtk_dialog_run (GTK_DIALOG (dialog), wbcg_toplevel (wbcg));
+		return;
+	} 
+	g_object_set_data (G_OBJECT (wb), SHEET_ORDER_KEY, (gpointer) gui);
 	state = g_new0 (SheetManager, 1);
 	state->gui = gui;
 	state->wbcg = wbcg;
@@ -1001,7 +1045,6 @@ dialog_sheet_order (WorkbookControlGUI *wbcg)
                                              GTK_ICON_SIZE_LARGE_TOOLBAR,
                                              "Gnumeric-Sheet-Manager");
 	/* Listen for changes in the sheet order. */
-	wb = wb_control_get_workbook (WORKBOOK_CONTROL (wbcg));
 	state->sheet_order_changed_listener = g_signal_connect (G_OBJECT (wb),
 		"sheet_order_changed", G_CALLBACK (cb_sheet_order_changed),
 		state);
