@@ -20,7 +20,7 @@
 #include <goffice/utils/go-glib-extras.h>
 #include <goffice/utils/go-libxml-extras.h>
 #include <gsf/gsf-impl-utils.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <string.h>
 
 typedef PluginServiceSimpleClass	PluginServiceFunctionGroupClass;
@@ -214,8 +214,8 @@ plugin_service_function_group_get_description (GOPluginService *service)
 		: service_function_group->category_name;
 
 	return g_strdup_printf (ngettext (
-			N_("%d function in category \"%s\""),
-			N_("Group of %d functions in category \"%s\""),
+			"%d function in category \"%s\"",
+			"Group of %d functions in category \"%s\"",
 			n_functions),
 		n_functions, category_name);
 }
@@ -404,8 +404,8 @@ plugin_service_ui_get_description (GOPluginService *service)
 	n_actions = g_slist_length (service_ui->actions);
 	return g_strdup_printf (
 		ngettext (
-			N_("User interface with %d action"),
-			N_("User interface with %d actions"),
+			"User interface with %d action",
+			"User interface with %d actions",
 			n_actions),
 		n_actions);
 }
@@ -436,7 +436,7 @@ typedef GOPluginLoaderModuleClass GnmPluginLoaderModuleClass;
 
 #define GNM_PLUGIN_LOADER_MODULE_TYPE (gnm_plugin_loader_module_get_type ())
 #define GNM_PLUGIN_LOADER_MODULE(o)  (G_TYPE_CHECK_INSTANCE_CAST ((o), GNM_PLUGIN_LOADER_MODULE_TYPE, GnmPluginLoaderModule))
-static GType gnm_plugin_loader_module_get_type (void);
+GType gnm_plugin_loader_module_get_type (void);
 
 /*
  * Service - function_group
@@ -558,7 +558,8 @@ gnm_plugin_loader_module_func_exec_action (GOPluginService *service,
 		return;
 	}
 	action_index = GPOINTER_TO_INT (action_index_ptr);
-	loader_data->module_ui_actions_array [action_index].handler (action, wbc);
+	if (NULL != loader_data->module_ui_actions_array [action_index].handler)
+		(*loader_data->module_ui_actions_array [action_index].handler) (action, wbc);
 }
 
 static void
@@ -637,9 +638,9 @@ go_plugin_loader_module_iface_init (GOPluginLoaderClass *iface)
 	iface->service_unload = gplm_service_unload;
 }
 
-static GSF_CLASS_FULL (GnmPluginLoaderModule, gnm_plugin_loader_module,
-           NULL, NULL,
-           GO_PLUGIN_LOADER_MODULE_TYPE, 0,
+GSF_CLASS_FULL (GnmPluginLoaderModule, gnm_plugin_loader_module,
+           NULL, NULL, NULL, NULL,
+           NULL, GO_PLUGIN_LOADER_MODULE_TYPE, 0,
 	   GSF_INTERFACE (go_plugin_loader_module_iface_init, GO_PLUGIN_LOADER_TYPE))
 
 /****************************************************************************/
