@@ -36,28 +36,28 @@
 #include <gtk/gtkimage.h>
 #include <gtk/gtkdnd.h>
 #include <gdk/gdkdisplay.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <math.h>
 #define GNUMERIC_ITEM "GnmPane"
 #include "item-debug.h"
 
 #undef DEBUG_DND
 
+static void cb_pane_popup_menu (GnmPane *pane);
+
 /**
  * For now, application/x-gnumeric is disabled. It handles neither
  * images nor graphs correctly.
  */
-static const GtkTargetEntry drag_types_in[] =
-	{
-		{(char *) "GNUMERIC_SAME_PROC", GTK_TARGET_SAME_APP, 0},
- 		/* {(char *) "application/x-gnumeric", 0, 0}, */
-	};
+static GtkTargetEntry const drag_types_in[] = {
+	{(char *) "GNUMERIC_SAME_PROC", GTK_TARGET_SAME_APP, 0},
+	/* {(char *) "application/x-gnumeric", 0, 0}, */
+};
 
-static const GtkTargetEntry drag_types_out[] =
-	{
-		{(char *) "GNUMERIC_SAME_PROC", GTK_TARGET_SAME_APP, 0},
-		{(char *) "application/x-gnumeric", 0, 0},
-	};
+static GtkTargetEntry const drag_types_out[] = {
+	{(char *) "GNUMERIC_SAME_PROC", GTK_TARGET_SAME_APP, 0},
+	{(char *) "application/x-gnumeric", 0, 0},
+};
 
 static void
 gnm_pane_header_realized (GtkWidget *widget)
@@ -95,7 +95,7 @@ gnumeric_pane_header_init (GnmPane *pane, SheetControlGUI *scg,
 	pane->size_guide.guide  = NULL;
 
 	if (NULL != scg &&
-	    NULL != (sheet = sc_sheet (SHEET_CONTROL (scg))) &&
+	    NULL != (sheet = scg_sheet (scg)) &&
 	    fabs (1. - sheet->last_zoom_factor_used) > 1e-6)
 		foo_canvas_set_pixels_per_unit (canvas, sheet->last_zoom_factor_used);
 
@@ -139,7 +139,7 @@ gnm_pane_display_obj_size_tip (GnmPane *pane, SheetObject const *so)
 
 	sheet_object_anchor_cpy	(&anchor, sheet_object_get_anchor (so));
 	scg_object_coords_to_anchor (scg, coords, &anchor);
-	sheet_object_anchor_to_pts (&anchor, sc_sheet (SHEET_CONTROL (scg)), pts);
+	sheet_object_anchor_to_pts (&anchor, scg_sheet (scg), pts);
 	msg = g_strdup_printf (_("%.1f x %.1f pts\n%d x %d pixels"),
 		MAX (fabs (pts[2] - pts[0]), 0),
 		MAX (fabs (pts[3] - pts[1]), 0),
@@ -149,31 +149,6 @@ gnm_pane_display_obj_size_tip (GnmPane *pane, SheetObject const *so)
 	g_free (msg);
 }
 
-static void
-cb_pane_popup_menu (GnmPane *pane)
-{
-	/* the popup-menu signal is a binding. the grid almost always has focus
-	 * we need to cheat to find out if the user realllllly wants a col/row
-	 * header menu */
-	gboolean is_col = FALSE;
-	gboolean is_row = FALSE;
-	GdkWindow *gdk_win = gdk_display_get_window_at_pointer (
-		gtk_widget_get_display (GTK_WIDGET (pane->gcanvas)),
-		NULL, NULL);
-
-	if (gdk_win != NULL) {
-		GtkWindow *gtk_win = NULL;
-		gdk_window_get_user_data (gdk_win, (gpointer *) &gtk_win);
-		if (gtk_win != NULL) {
-			if (gtk_win == (GtkWindow *)pane->col.canvas)
-				is_col = TRUE;
-			else if (gtk_win == (GtkWindow *)pane->row.canvas)
-				is_row = TRUE;
-		}
-	}
-	scg_context_menu (pane->gcanvas->simple.scg, NULL, is_col, is_row);
-}
-
 static void
 cb_ctrl_pts_free (GtkObject **ctrl_pts)
 {
@@ -236,18 +211,32 @@ cb_pane_drag_motion (GtkWidget *widget, GdkDragContext *context,
 		double wx, wy;
 
 		g_object_set_data (&context->parent_instance,
-			"wbcg", scg_get_wbcg (scg));
+			"wbcg", scg_wbcg (scg));
 		gnm_canvas_window_to_coord (gcanvas, x, y, &wx, &wy);
 
-		gdk_window_get_pointer (gtk_widget_get_parent_window (widget),
+		gdk_window_get_pointer (gtk_widget_get_parent_window (source_widget),
 			NULL, NULL, &mask);
 		gnm_pane_objects_drag (GNM_CANVAS (source_widget)->pane, NULL,
 			wx, wy, 8, FALSE, (mask & GDK_SHIFT_MASK) != 0);
-		gdk_drag_status (context, GDK_ACTION_MOVE, time);
+		gdk_drag_status (context, 
+				 (mask & GDK_CONTROL_MASK) != 0 ? GDK_ACTION_COPY : GDK_ACTION_MOVE, 
+				 time);
 	}
 	return TRUE;
 }
 
+static void
+cb_pane_drag_end (GtkWidget *widget, GdkDragContext *context,
+		  GnmPane *source_pane)
+{
+	/* sync the ctrl-pts with the object in case the drag was canceled. */
+	gnm_pane_objects_drag (source_pane, NULL,
+		source_pane->drag.origin_x,
+		source_pane->drag.origin_y,
+		8, FALSE, FALSE);
+	source_pane->drag.had_motion = FALSE;
+}
+
 /**
  * Move the rubber bands back to original position when curser leaves
  * the scg, but not when it moves to another pane. We use object data,
@@ -261,21 +250,19 @@ cb_pane_drag_leave (GtkWidget *widget, GdkDragContext *context,
 	GtkWidget *source_widget = gtk_drag_get_source_widget (context);
 	GnmPane *source_pane;
 	WorkbookControlGUI *wbcg;
-
-	if (!source_widget) return;
-
-	g_return_if_fail (IS_GNM_CANVAS (source_widget));
+  
+	if (!source_widget || !IS_GNM_CANVAS (source_widget)) return;
 
 	source_pane = GNM_CANVAS (source_widget)->pane;
 
-	wbcg = scg_get_wbcg (source_pane->gcanvas->simple.scg);
+	wbcg = scg_wbcg (source_pane->gcanvas->simple.scg);
 	if (wbcg == g_object_get_data (&context->parent_instance, "wbcg"))
 		return;
 
 	gnm_pane_objects_drag (source_pane, NULL,
-			       source_pane->drag.origin_x,
-			       source_pane->drag.origin_y,
-			       8, FALSE, FALSE);
+		source_pane->drag.origin_x,
+		source_pane->drag.origin_y,
+		8, FALSE, FALSE);
 	source_pane->drag.had_motion = FALSE;
 }
 
@@ -296,6 +283,7 @@ gnm_pane_drag_dest_init (GnmPane *pane, SheetControlGUI *scg)
 		"signal::drag-data-get",	G_CALLBACK (cb_pane_drag_data_get),	scg,
 		"signal::drag-motion",		G_CALLBACK (cb_pane_drag_motion),	pane,
 		"signal::drag-leave",		G_CALLBACK (cb_pane_drag_leave),	pane,
+		"signal::drag-end",		G_CALLBACK (cb_pane_drag_end),		pane,
 		NULL);
 }
 
@@ -303,7 +291,7 @@ static void
 cb_pane_init_objs (GnmPane *pane)
 {
 	/* create views for the sheet objects now that we exist */
-	Sheet *sheet = sc_sheet (SHEET_CONTROL (pane->gcanvas->simple.scg));
+	Sheet *sheet = scg_sheet (pane->gcanvas->simple.scg);
 	GSList *ptr;
 
 	if (sheet != NULL)
@@ -331,7 +319,7 @@ gnm_pane_init (GnmPane *pane, SheetControlGUI *scg,
 		G_CALLBACK (cb_pane_init_objs), pane);
 
 	if (NULL != scg &&
-	    NULL != (sheet = sc_sheet (SHEET_CONTROL (scg))) &&
+	    NULL != (sheet = scg_sheet (scg)) &&
 	    fabs (1. - sheet->last_zoom_factor_used) > 1e-6)
 		foo_canvas_set_pixels_per_unit (FOO_CANVAS (pane->gcanvas),
 						sheet->last_zoom_factor_used);
@@ -601,19 +589,19 @@ void
 gnm_pane_rangesel_start (GnmPane *pane, GnmRange const *r)
 {
 	FooCanvasItem *item;
-	SheetControl *sc = (SheetControl *) pane->gcanvas->simple.scg;
+	SheetControlGUI *scg = pane->gcanvas->simple.scg;
 
 	g_return_if_fail (pane->cursor.rangesel == NULL);
 
 	/* Hide the primary cursor while the range selection cursor is visible
 	 * and we are selecting on a different sheet than the expr being edited
 	 */
-	if (sc_sheet (sc) != wb_control_cur_sheet (sc_wbc (sc)))
+	if (scg_sheet (scg) != wb_control_cur_sheet (scg_wbc (scg)))
 		item_cursor_set_visibility (pane->cursor.std, FALSE);
 
 	item = foo_canvas_item_new (pane->gcanvas->grid_items,
 		item_cursor_get_type (),
-		"SheetControlGUI", pane->gcanvas->simple.scg,
+		"SheetControlGUI", scg,
 		"style",	ITEM_CURSOR_ANTED,
 		NULL);
 	pane->cursor.rangesel = ITEM_CURSOR (item);
@@ -691,7 +679,7 @@ void
 gnm_pane_edit_start (GnmPane *pane)
 {
 	GnmCanvas const *gcanvas = pane->gcanvas;
-	SheetView const *sv = sc_view (SHEET_CONTROL (gcanvas->simple.scg));
+	SheetView const *sv = scg_view (gcanvas->simple.scg);
 	GnmCellPos const *edit_pos;
 
 	g_return_if_fail (pane->editor == NULL);
@@ -839,6 +827,7 @@ cb_ptr_array_free (GPtrArray *actions)
 	g_ptr_array_free (actions, TRUE);
 }
 
+/* event and so can be NULL */
 static void
 display_object_menu (GnmPane *pane, SheetObject *so, GdkEvent *event)
 {
@@ -847,9 +836,11 @@ display_object_menu (GnmPane *pane, SheetObject *so, GdkEvent *event)
 	GtkWidget *menu;
 	unsigned i = 0;
 
-	if (NULL == g_hash_table_lookup (scg->selected_objects, so))
+	if (NULL != so &&
+	    NULL == g_hash_table_lookup (scg->selected_objects, so))
 		scg_object_select (scg, so);
-	SHEET_OBJECT_CLASS (G_OBJECT_GET_CLASS(so))->populate_menu (so, actions);
+
+	sheet_object_populate_menu (so, actions);
 
 	if (actions->len == 0) {
 		g_ptr_array_free (actions, TRUE);
@@ -865,6 +856,53 @@ display_object_menu (GnmPane *pane, SheetObject *so, GdkEvent *event)
 	gnumeric_popup_menu (GTK_MENU (menu), &event->button);
 }
 
+static void
+cb_collect_selected_objs (SheetObject *so, double *coords, GSList **accum)
+{
+	*accum = g_slist_prepend (*accum, so);
+}
+
+static void
+cb_pane_popup_menu (GnmPane *pane)
+{
+	SheetControlGUI *scg = pane->gcanvas->simple.scg;
+
+	/* ignore new_object, it is not visible, and should not create a
+	 * context menu */
+	if (NULL != scg->selected_objects) {
+		GSList *accum = NULL;
+		g_hash_table_foreach (scg->selected_objects,
+			(GHFunc) cb_collect_selected_objs, &accum);
+		if (NULL != accum && NULL == accum->next)
+			display_object_menu (pane, accum->data, NULL);
+		g_slist_free (accum);
+	} else {
+		/* the popup-menu signal is a binding. the grid almost always
+		 * has focus we need to cheat to find out if the user
+		 * realllllly wants a col/row header menu */
+		gboolean is_col = FALSE;
+		gboolean is_row = FALSE;
+		GdkWindow *gdk_win = gdk_display_get_window_at_pointer (
+			gtk_widget_get_display (GTK_WIDGET (pane->gcanvas)),
+			NULL, NULL);
+
+		if (gdk_win != NULL) {
+			gpointer gtk_win_void = NULL;
+			GtkWindow *gtk_win = NULL;
+			gdk_window_get_user_data (gdk_win, &gtk_win_void);
+			gtk_win = gtk_win_void;
+			if (gtk_win != NULL) {
+				if (gtk_win == (GtkWindow *)pane->col.canvas)
+					is_col = TRUE;
+				else if (gtk_win == (GtkWindow *)pane->row.canvas)
+					is_row = TRUE;
+			}
+		}
+
+		scg_context_menu (scg, NULL, is_col, is_row);
+	}
+}
+
 static void
 control_point_set_cursor (SheetControlGUI const *scg, FooCanvasItem *ctrl_pt)
 {
@@ -987,33 +1025,12 @@ void
 gnm_pane_object_start_resize (GnmPane *pane, GdkEventButton *event,
 			      SheetObject *so, int drag_type, gboolean is_creation)
 {
-	/* ctrl-click on acetate dups the object */
-	gboolean const make_dup = drag_type == 8 &&
-		(event->state & GDK_CONTROL_MASK);
 	FooCanvasItem **ctrl_pts;
 
 	g_return_if_fail (IS_SHEET_OBJECT (so));
 	g_return_if_fail (0 <= drag_type);
 	g_return_if_fail (drag_type < 9);
 
-	if (make_dup) {
-		SheetControlGUI *scg = pane->gcanvas->simple.scg;
-		GSList *ptr, *objs = go_hash_keys (scg->selected_objects);
-
-		for (ptr = objs ; ptr != NULL ; ptr = ptr->next) {
-			SheetObject *dup_obj = sheet_object_dup (ptr->data);
-			if (dup_obj != NULL) {
-				sheet_object_set_sheet (dup_obj, sc_sheet (SHEET_CONTROL (scg)));
-				scg_object_select (scg, dup_obj);
-				g_object_unref (dup_obj);
-				scg_object_unselect (scg, ptr->data);
-				if (so == ptr->data)
-					so = dup_obj;
-			}
-		}
-		g_slist_free (objs);
-	}
-
 	ctrl_pts = g_hash_table_lookup (pane->drag.ctrl_pts, so);
 
 	g_return_if_fail (NULL != ctrl_pts);
@@ -1023,7 +1040,7 @@ gnm_pane_object_start_resize (GnmPane *pane, GdkEventButton *event,
 		GDK_BUTTON_PRESS_MASK |
 		GDK_BUTTON_RELEASE_MASK,
 		NULL, event->time);
-	pane->drag.created_objects = is_creation || make_dup;
+	pane->drag.created_objects = is_creation;
 	pane->drag.button = event->button;
 	pane->drag.last_x = pane->drag.origin_x = event->x;
 	pane->drag.last_y = pane->drag.origin_y = event->y;
@@ -1040,7 +1057,7 @@ cb_control_point_event (FooCanvasItem *ctrl_pt, GdkEvent *event, GnmPane *pane)
 	SheetObject *so;
 	int idx;
 
-	if (wbcg_edit_get_guru (scg_get_wbcg (scg)) != NULL)
+	if (wbcg_edit_get_guru (scg_wbcg (scg)) != NULL)
 		return FALSE;
 
 	so  = g_object_get_data (G_OBJECT (ctrl_pt), "so");
@@ -1080,7 +1097,9 @@ cb_control_point_event (FooCanvasItem *ctrl_pt, GdkEvent *event, GnmPane *pane)
 		gnm_simple_canvas_ungrab (ctrl_pt, event->button.time);
 		gnm_canvas_slide_stop (gcanvas);
 		control_point_set_cursor (scg, ctrl_pt);
-		if (pane->drag.had_motion)
+		if (idx == 8)
+			; /* ignore fake event generated by the dnd code */
+		else if (pane->drag.had_motion)
 			scg_objects_drag_commit	(scg, idx,
 				pane->drag.created_objects);
 		else if (pane->drag.created_objects && idx == 7) {
@@ -1120,16 +1139,17 @@ cb_control_point_event (FooCanvasItem *ctrl_pt, GdkEvent *event, GnmPane *pane)
 		 * the semantics of the col,row args in the callback.  However,
 		 * that is more work than I want to do right now.
 		 */
-		if (idx == 8 &&  !pane->drag.created_objects)
+		if (idx == 8) 
 			gnm_pane_drag_begin (pane, so, event);
 		else if (gnm_canvas_handle_motion (GNM_CANVAS (ctrl_pt->canvas),
 						   ctrl_pt->canvas, &event->motion,
-						   GNM_CANVAS_SLIDE_X | GNM_CANVAS_SLIDE_Y | GNM_CANVAS_SLIDE_EXTERIOR_ONLY,
+						   GNM_CANVAS_SLIDE_X | GNM_CANVAS_SLIDE_Y |
+						   GNM_CANVAS_SLIDE_EXTERIOR_ONLY,
 						   cb_slide_handler, ctrl_pt))
 			gnm_pane_object_move (pane, G_OBJECT (ctrl_pt),
-				event->motion.x, event->motion.y,
-				(event->button.state & GDK_CONTROL_MASK) != 0,
-				(event->button.state & GDK_SHIFT_MASK) != 0);
+					      event->motion.x, event->motion.y,
+					      (event->button.state & GDK_CONTROL_MASK) != 0,
+					      (event->button.state & GDK_SHIFT_MASK) != 0);
 		break;
 
 	default:
@@ -1349,7 +1369,7 @@ cb_sheet_object_canvas_event (FooCanvasItem *view, GdkEvent *event,
 	case GDK_ENTER_NOTIFY:
 		gnm_widget_set_cursor_type (GTK_WIDGET (view->canvas),
 			(so->flags & SHEET_OBJECT_CAN_PRESS) ? GDK_HAND2 : GDK_ARROW);
-		break;
+		return FALSE;
 
 	case GDK_BUTTON_PRESS:
 		if (event->button.button > 3)
@@ -1357,6 +1377,12 @@ cb_sheet_object_canvas_event (FooCanvasItem *view, GdkEvent *event,
 
 		/* cb_sheet_object_widget_canvas_event calls even if selected */
 		if (NULL == g_hash_table_lookup (pane->drag.ctrl_pts, so)) {
+			SheetObjectClass *soc =
+				G_TYPE_INSTANCE_GET_CLASS (so, SHEET_OBJECT_TYPE, SheetObjectClass);
+
+			if (soc->interactive && event->button.button != 3)
+				return FALSE;
+
 			if (!(event->button.state & GDK_SHIFT_MASK))
 				scg_object_unselect (pane->gcanvas->simple.scg, NULL);
 			scg_object_select (pane->gcanvas->simple.scg, so);
@@ -1379,9 +1405,12 @@ cb_sheet_object_canvas_event (FooCanvasItem *view, GdkEvent *event,
 static void
 cb_sheet_object_view_destroyed (FooCanvasItem *view, SheetObject *so)
 {
-	GnmPane *pane = GNM_CANVAS (view->canvas)->pane;
-	if (pane != NULL && g_hash_table_lookup (pane->drag.ctrl_pts, so) != NULL)
-		scg_object_unselect (GNM_SIMPLE_CANVAS (view->canvas)->scg, so);
+	if (NULL != view->canvas) {
+		GnmPane *pane = GNM_CANVAS (view->canvas)->pane;
+		if (pane != NULL &&
+		    g_hash_table_lookup (pane->drag.ctrl_pts, so) != NULL)
+			scg_object_unselect (GNM_SIMPLE_CANVAS (view->canvas)->scg, so);
+	}
 }
 
 static int
@@ -1392,13 +1421,6 @@ cb_sheet_object_widget_canvas_event (GtkWidget *widget, GdkEvent *event,
 	    (event->type == GDK_BUTTON_PRESS && event->button.button == 3))
 		return cb_sheet_object_canvas_event (view, event,
 			sheet_object_view_get_so (SHEET_OBJECT_VIEW (view)));
-	if (event->type == GDK_2BUTTON_PRESS && event->button.button == 1) {
-		sheet_object_get_editor (
-			sheet_object_view_get_so (SHEET_OBJECT_VIEW (view)),
-			SHEET_CONTROL (GNM_SIMPLE_CANVAS (view->canvas)->scg));
-		return TRUE;
-	}
-
 	return FALSE;
 }
 
