@@ -263,7 +263,7 @@ gnm_go_data_scalar_finalize (GObject *obj)
 	g_free (scalar->val_str);
 	scalar->val_str = NULL;
 
-	(*scalar_parent_klass->finalize) (obj);
+	scalar_parent_klass->finalize (obj);
 }
 
 static double
@@ -362,12 +362,11 @@ gnm_go_data_vector_finalize (GObject *obj)
 		value_release (vec->val);
 		vec->val = NULL;
 	}
-	if (vec->base.values != NULL) {
-		g_free (vec->base.values);
-		vec->base.values = NULL;
-	}
 
-	(*vector_parent_klass->finalize) (obj);
+	g_free (vec->base.values);
+	vec->base.values = NULL;
+
+	vector_parent_klass->finalize (obj);
 }
 
 static void
@@ -447,7 +446,7 @@ cb_assign_val (GnmCellIter const *iter, struct assign_closure *dat)
 	double res;
 
 	if (iter->cell != NULL) {
-		cell_eval (iter->cell);
+		gnm_cell_eval (iter->cell);
 		v = iter->cell->value;
 	} else
 		v = NULL;
@@ -648,9 +647,9 @@ gnm_go_data_vector_get_str (GODataVector *dat, unsigned i)
 		cell = sheet_cell_get (start_sheet, r.start.col, r.start.row);
 		if (cell == NULL)
 			return NULL;
-		cell_eval (cell);
+		gnm_cell_eval (cell);
 		v = cell->value;
-		format = cell_get_format (cell);
+		format = gnm_cell_get_format (cell);
 		date_conv = workbook_date_conv (start_sheet->workbook);
 	} else if (v->type == VALUE_ARRAY)
 		v = vec->as_col
@@ -749,12 +748,11 @@ gnm_go_data_matrix_finalize (GObject *obj)
 		value_release (mat->val);
 		mat->val = NULL;
 	}
-	if (mat->base.values != NULL) {
-		g_free (mat->base.values);
-		mat->base.values = NULL;
-	}
 
-	(*matrix_parent_klass->finalize) (obj);
+	g_free (mat->base.values);
+	mat->base.values = NULL;
+
+	matrix_parent_klass->finalize (obj);
 }
 
 static void
@@ -851,7 +849,7 @@ cb_assign_matrix_val (GnmCellIter const *iter,
 	dat->row = iter->pp.eval.row - dat->first_row;
 
 	if (iter->cell != NULL) {
-		cell_eval (iter->cell);
+		gnm_cell_eval (iter->cell);
 		v = iter->cell->value;
 	} else
 		v = NULL;
@@ -1052,9 +1050,9 @@ gnm_go_data_matrix_get_str (GODataMatrix *dat, unsigned i, unsigned j)
 		cell = sheet_cell_get (start_sheet, r.start.col, r.start.row);
 		if (cell == NULL)
 			return NULL;
-		cell_eval (cell);
+		gnm_cell_eval (cell);
 		v = cell->value;
-		format = cell_get_format (cell);
+		format = gnm_cell_get_format (cell);
 		date_conv = workbook_date_conv (start_sheet->workbook);
 	} else if (v->type == VALUE_ARRAY)
 		v = value_area_get_x_y (v, i, j, &ep);
