@@ -95,7 +95,7 @@ void         gnm_style_set_border	   (GnmStyle *style, GnmStyleElement elem,
 GnmBorder   *gnm_style_get_border	   (GnmStyle const *style, GnmStyleElement elem);
 void         gnm_style_set_pattern	   (GnmStyle *style, int pattern);
 int          gnm_style_get_pattern	   (GnmStyle const *style);
-void         gnm_style_set_font_name	   (GnmStyle *style, const char *name);
+void         gnm_style_set_font_name	   (GnmStyle *style, char const *name);
 char const  *gnm_style_get_font_name	   (GnmStyle const *style);
 void         gnm_style_set_font_bold	   (GnmStyle *style, gboolean bold);
 gboolean     gnm_style_get_font_bold	   (GnmStyle const *style);
@@ -110,7 +110,6 @@ GOFontScript gnm_style_get_font_script	   (GnmStyle const *style);
 void         gnm_style_set_font_size	   (GnmStyle *style, float size);
 float        gnm_style_get_font_size	   (GnmStyle const *style);
 
-/* this font must be unrefd after use */
 GnmFont     *gnm_style_get_font		   (GnmStyle const *style,
 					    PangoContext *context,
 					    float zoom);
@@ -159,8 +158,11 @@ PangoAttrList	*gnm_style_generate_attrs_full (GnmStyle const *style);
 PangoAttrList	*gnm_style_get_pango_attrs     (GnmStyle const *style,
 						PangoContext *context,
 						float zoom);
+int              gnm_style_get_pango_height    (GnmStyle const *style,
+						PangoContext *context,
+						float zoom);
 void   	    gnm_style_set_from_pango_attribute (GnmStyle *style,
-						     PangoAttribute const *attr);
+						PangoAttribute const *attr);
 
 void        gnm_style_init (void);
 void        gnm_style_shutdown (void);
