@@ -239,8 +239,8 @@ r1c1_add_index (GString *target, char type, int num, unsigned char relative)
 static char *
 wb_rel_uri (Workbook *wb, Workbook *ref_wb)
 {
-	const char *uri = go_doc_get_uri ((GODoc *)wb);
-	const char *ref_uri = go_doc_get_uri ((GODoc *)ref_wb);
+	char const *uri = go_doc_get_uri ((GODoc *)wb);
+	char const *ref_uri = go_doc_get_uri ((GODoc *)ref_wb);
 	char *rel_uri = go_url_make_relative (uri, ref_uri);
 
 	if (rel_uri == NULL || rel_uri[0] == '/') {
@@ -731,9 +731,7 @@ parse_text_value_or_expr (GnmParsePos const *pos, char const *text,
 	expr_start = gnm_expr_char_start_p (text);
 	if (NULL != expr_start && *expr_start) {
 		*texpr = gnm_expr_parse_str (expr_start, pos,
-					     GNM_EXPR_PARSE_DEFAULT,
-					     gnm_expr_conventions_default,
-					     NULL);
+			GNM_EXPR_PARSE_DEFAULT, NULL, NULL);
 		if (*texpr != NULL)
 			return;
 	}
@@ -929,8 +927,6 @@ sheetref_parse (char const *start, Sheet **sheet, Workbook const *wb,
 	return end;
 }
 
-/* An odd little routine that is called when we start parsing looking for an A1
- * style ref and get into a situation that may be an R1C1 */
 static char const *
 r1c1_rangeref_parse (GnmRangeRef *res, char const *ptr, GnmParsePos const *pp)
 {
@@ -1183,7 +1179,7 @@ std_sheet_name_quote (GnmExprConventions const *convs,
 {
 	gunichar uc = g_utf8_get_char (str);
 	GString *res = g_string_sized_new (20);
-	const char *p;
+	char const *p;
 	int nletters;
 	int ndigits;
 
@@ -1256,8 +1252,8 @@ std_sheet_name_quote (GnmExprConventions const *convs,
 	return res;
 }
 
-static const char *
-std_name_parser (const char *str,
+static char const *
+std_name_parser (char const *str,
 		 G_GNUC_UNUSED GnmExprConventions const *convs)
 {
 	gunichar uc = g_utf8_get_char (str);
@@ -1477,8 +1473,7 @@ parse_util_shutdown (void)
 GnmExprTop const *
 gnm_expr_parse_str_simple (char const *expr, GnmParsePos const *pp)
 {
-	return gnm_expr_parse_str (expr, pp, GNM_EXPR_PARSE_DEFAULT,
-				   gnm_expr_conventions_default, NULL);
+	return gnm_expr_parse_str (expr, pp, GNM_EXPR_PARSE_DEFAULT, NULL, NULL);
 }
 
 /* ------------------------------------------------------------------------- */
