@@ -2,8 +2,7 @@
 #define GNUMERIC_SYMBOL_H
 
 typedef enum {
-	SYMBOL_FUNCTION,
-	SYMBOL_VALUE,
+	SYMBOL_FUNCTION
 } SymbolType;
 
 typedef struct {
@@ -21,19 +20,11 @@ typedef struct {
 SymbolTable *symbol_table_new      (void);
 void         symbol_table_destroy  (SymbolTable *st);
 
-Symbol      *symbol_lookup         (SymbolTable *st, const char *str);
-Symbol      *symbol_lookup_substr  (SymbolTable *st, const char *buffer, int len);
-Symbol      *symbol_install        (SymbolTable *st, const char *str,
+Symbol      *symbol_lookup         (SymbolTable *st, char const *str);
+Symbol      *symbol_install        (SymbolTable *st, char const *str,
 				    SymbolType type, void *data);
-void         symbol_remove         (SymbolTable *st, Symbol *);
-gboolean     symbol_is_unused      (Symbol *);
 
 void         symbol_ref            (Symbol *);
 void         symbol_unref          (Symbol *);
-void         symbol_unref_ptr      (Symbol **);
-
-void         global_symbol_init    (void);
-
-extern SymbolTable *global_symbol_table;
 
 #endif /* GNUMERIC_SYMBOL_H */
