@@ -3,7 +3,7 @@
 /*
  * wbcg-actions.c: The callbacks and tables for all the menus and stock toolbars
  *
- * Copyright (C) 2003-2005 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2003-2006 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -19,16 +19,12 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  *
- * Port to Maemo:
- * 	Eduardo Lima  (eduardo.lima@indt.org.br)
- * 	Renato Araujo (renato.filho@indt.org.br)
  */
 #include <gnumeric-config.h>
 #include "gnumeric.h"
 
 #include "libgnumeric.h"
 #include "application.h"
-#include "print.h"
 #include "commands.h"
 #include "clipboard.h"
 #include "selection.h"
@@ -54,7 +50,6 @@
 #include "workbook-view.h"
 #include "workbook-edit.h"
 #include "workbook-control-gui-priv.h"
-#include "workbook-control.h"
 #include "workbook-cmd-format.h"
 #include "dialogs/dialogs.h"
 #include "sheet-object-image.h"
@@ -65,6 +60,11 @@
 #include "gui-util.h"
 #include "gui-file.h"
 #include "gnumeric-gconf.h"
+#include "expr.h"
+
+#ifdef WITH_GNOME_PRINT
+#include "print.h"
+#endif
 
 #include <goffice/app/io-context.h>
 #include <goffice/graph/gog-guru.h>
@@ -77,55 +77,18 @@
 #include <gtk/gtkactiongroup.h>
 #include <gtk/gtktoggleaction.h>
 #include <gtk/gtkstock.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <gsf/gsf-input.h>
 #include <string.h>
 
-#ifdef USE_HILDON
-#include <wbc-gtk.h>
-#include <hildon-lgpl/hildon-widgets/hildon-appview.h>
-#include <hildon-widgets/hildon-color-selector.h>
-#include <hildon-widgets/hildon-font-selection-dialog.h>
-#endif
-
 static GNM_ACTION_DEF (cb_file_new)
 {
 	GdkScreen *screen = gtk_window_get_screen (wbcg_toplevel (wbcg));
 	Workbook *wb = workbook_new_with_sheets
 		(gnm_app_prefs->initial_sheet_number);
-
-#ifdef USE_HILDON
-	WorkbookControl * wbc = (WorkbookControl *) wbcg;
-	Workbook *tmp_wb = wb_control_workbook (WORKBOOK_CONTROL (wbcg));
-
-	if (workbook_is_dirty (tmp_wb)) {
-		switch (wbcg_show_save_dialog (wbcg, tmp_wb, FALSE)) {
-
-			case GTK_RESPONSE_YES:
-			case GNM_RESPONSE_SAVE_ALL:
-				gui_file_save (wbcg, wb_control_view (WORKBOOK_CONTROL (wbcg)));
-				break;
-
-			case GTK_RESPONSE_NO:
-			case GNM_RESPONSE_DISCARD_ALL:
-				/* Do nothing */
-				break;
-			
-			default:  /* CANCEL */
-				return;
-		}
-	}
-
-	g_object_ref (wbcg);
-	g_object_unref (wb_control_workbook (WORKBOOK_CONTROL (wbcg)));
-	wb_control_set_view (wbc, NULL, wb);
-	wb_control_init_state (wbc);
-	sheet_update (wb_view_cur_sheet (wb_control_view (wbc)));
-#else
 	WorkbookControl *new_wbc = workbook_control_gui_new (NULL, wb, screen);
 	WorkbookControlGUI *new_wbcg = WORKBOOK_CONTROL_GUI (new_wbc);
 	wbcg_copy_toolbar_visibility (new_wbcg, wbcg);	
-#endif
 }
 
 static GNM_ACTION_DEF (cb_file_open)	{ gui_file_open (wbcg, NULL); }
@@ -133,12 +96,72 @@ static GNM_ACTION_DEF (cb_file_save)	{ gui_file_save (wbcg, wb_control_view (WOR
 static GNM_ACTION_DEF (cb_file_save_as)	{ gui_file_save_as (wbcg, wb_control_view (WORKBOOK_CONTROL (wbcg))); }
 static GNM_ACTION_DEF (cb_file_sendto)	{
 	wb_view_sendto (wb_control_view (WORKBOOK_CONTROL (wbcg)), GO_CMD_CONTEXT (wbcg)); }
-static GNM_ACTION_DEF (cb_file_page_setup) { dialog_printer_setup (wbcg, wbcg_cur_sheet (wbcg)); }
-static GNM_ACTION_DEF (cb_file_print)	{
-	sheet_print (wbcg, wbcg_cur_sheet (wbcg), FALSE, PRINT_ACTIVE_SHEET); }
-static GNM_ACTION_DEF (cb_file_print_preview) {
-	sheet_print (wbcg, wbcg_cur_sheet (wbcg), TRUE, PRINT_ACTIVE_SHEET); }
-static GNM_ACTION_DEF (cb_file_summary)		{ dialog_summary_update (wbcg, TRUE); }
+static GNM_ACTION_DEF (cb_file_page_setup)
+{ 
+#ifdef WITH_GNOME_PRINT
+	dialog_printer_setup (wbcg, wbcg_cur_sheet (wbcg));
+#endif
+}
+
+static GNM_ACTION_DEF (cb_file_print_area_set) {
+	Sheet *sheet = wbcg_cur_sheet (wbcg);
+	SheetView *sv = sheet_get_view (sheet, wb_control_view (WORKBOOK_CONTROL (wbcg)));
+	GnmParsePos pp;
+	char *message;
+	char * selection;
+	GnmRange const *r = selection_first_range (sv,
+				       GO_CMD_CONTEXT (wbcg), _("Set Print Area"));;
+	if (r != NULL) {
+		parse_pos_init_sheet (&pp, sheet);
+		selection = undo_range_name (sheet, r);
+		message = g_strdup_printf (_("Set Print Area to %s"), selection);
+		cmd_define_name	(WORKBOOK_CONTROL (wbcg), "Print_Area", &pp,
+				 gnm_expr_top_new_constant
+				 (value_new_cellrange_r (NULL, r)),
+				 message);
+		g_free (selection);
+		g_free (message);
+	}
+}
+
+static GNM_ACTION_DEF (cb_file_print_area_clear) {
+	GnmParsePos pp;
+	GnmRange r;
+	
+	range_init_full_sheet (&r);
+	parse_pos_init_sheet (&pp, wbcg_cur_sheet (wbcg));
+	cmd_define_name	(WORKBOOK_CONTROL (wbcg), "Print_Area", &pp,
+			 gnm_expr_top_new_constant
+			 (value_new_cellrange_r (NULL, &r)),
+			 _("Clear Print Area"));
+}
+
+static GNM_ACTION_DEF (cb_file_print_area_show) {
+	Sheet *sheet = wbcg_cur_sheet (wbcg);
+	SheetView *sv = sheet_get_view (sheet, wb_control_view (WORKBOOK_CONTROL (wbcg)));
+	GnmRange r = sheet_get_nominal_printarea (sheet);
+	
+	wb_control_sheet_focus (WORKBOOK_CONTROL (wbcg), sheet);
+	sv_selection_reset (sv);
+	sv_selection_add_range (sv, &r);
+	sv_make_cell_visible (sv, r.start.col, r.start.row, FALSE);
+}
+
+static GNM_ACTION_DEF (cb_file_print)
+{
+#ifdef WITH_GNOME_PRINT
+	gnm_print_sheet (wbcg, wbcg_cur_sheet (wbcg), FALSE, PRINT_ACTIVE_SHEET);
+#endif
+}
+
+static GNM_ACTION_DEF (cb_file_print_preview)
+{
+#ifdef WITH_GNOME_PRINT
+	gnm_print_sheet (wbcg, wbcg_cur_sheet (wbcg), TRUE, PRINT_ACTIVE_SHEET);
+#endif
+}
+
+static GNM_ACTION_DEF (cb_doc_meta_data)	{ dialog_doc_metadata_new (wbcg); }
 static GNM_ACTION_DEF (cb_file_preferences)	{ dialog_preferences (wbcg, 0); }
 static GNM_ACTION_DEF (cb_file_close)		{ wbcg_close_control (wbcg); }
 
@@ -170,7 +193,7 @@ static GNM_ACTION_DEF (cb_file_quit)
 		g_return_if_fail (IS_WORKBOOK (wb));
 		g_return_if_fail (wb->wb_views != NULL);
 
-		if (wb_control_workbook (wbc) == wb)
+		if (wb_control_get_workbook (wbc) == wb)
 			continue;
 		if (discard_all) {
 
@@ -191,25 +214,24 @@ static GNM_ACTION_DEF (cb_file_quit)
 				discard_all = TRUE;
 				old_ptr = ptr;
 				for (ptr = ptr->next; ptr != NULL ; ptr = ptr->next) {
-					Workbook *wba = ptr->data;
+					GODoc *wb = ptr->data;
 					old_ptr = ptr;
-					if (wb_control_workbook (wbc) == wba)
+					if (wb_control_get_doc (wbc) == wb)
 						continue;
-					workbook_set_dirty (wba, FALSE);
-					g_object_unref (wba);
+					go_doc_set_dirty (wb, FALSE);
+					g_object_unref (wb);
 				}
 				ptr = old_ptr;
 				break;
-			};
+			}
 		}
 	}
 
 	if (discard_all) {
-		workbook_set_dirty (wb_control_workbook (wbc), FALSE);
-		g_object_unref (wb_control_workbook (wbc));
-		for (ptr = clean_no_closed; ptr != NULL ; ptr = ptr->next) {
+		go_doc_set_dirty (wb_control_get_doc (wbc), FALSE);
+		g_object_unref (wb_control_get_doc (wbc));
+		for (ptr = clean_no_closed; ptr != NULL ; ptr = ptr->next)
 			g_object_unref (ptr->data);
-		}
 	} else if (ok && wbcg_close_if_user_permits (wbcg, wb_control_view (wbc),
 						     TRUE, TRUE, ask_user) > 0)
 		/* only close pristine books if nothing was canceled. */
@@ -219,11 +241,6 @@ static GNM_ACTION_DEF (cb_file_quit)
 	g_list_free (workbooks);
 	g_list_free (clean_no_closed);
 }
-static GNM_ACTION_DEF (cb_new_doc_metadata)
-{
-	dialog_doc_metadata_new (wbcg);
-}
-
 /****************************************************************************/
 
 static GNM_ACTION_DEF (cb_edit_clear_all)
@@ -345,22 +362,13 @@ static GNM_ACTION_DEF (cb_edit_paste_special)
 
 static GNM_ACTION_DEF (cb_sheet_remove)
 {
-	SheetControlGUI *res;
-	if (wbcg_sheet_to_page_index (wbcg, wbcg_cur_sheet (wbcg), &res) >= 0)
-		scg_delete_sheet_if_possible (NULL, res);
+	SheetControlGUI *scg = wbcg_cur_scg (wbcg);
+	if (scg)
+		scg_delete_sheet_if_possible (NULL, scg);
 }
 
-static GNM_ACTION_DEF (cb_edit_duplicate_sheet)
-{
-	WorkbookControl *wbc = WORKBOOK_CONTROL (wbcg);
-	Sheet *old_sheet = wb_control_cur_sheet (wbc);
-	cmd_clone_sheet (wbc, old_sheet);
-}
-
-#ifdef USE_HILDON
-static GNM_ACTION_DEF (cb_edit_undo) { command_undo (WORKBOOK_CONTROL (wbcg)); }
-static GNM_ACTION_DEF (cb_edit_redo) { command_redo (WORKBOOK_CONTROL (wbcg)); }
-#endif
+static GNM_ACTION_DEF (cb_edit_undo_last) { command_undo (WORKBOOK_CONTROL (wbcg)); }
+static GNM_ACTION_DEF (cb_edit_redo_last) { command_redo (WORKBOOK_CONTROL (wbcg)); }
 
 static void
 common_cell_goto (WorkbookControlGUI *wbcg, Sheet *sheet, GnmCellPos const *pos)
@@ -376,23 +384,20 @@ common_cell_goto (WorkbookControlGUI *wbcg, Sheet *sheet, GnmCellPos const *pos)
 }
 
 static int
-cb_edit_search_replace_query (SearchReplaceQuery q, GnmSearchReplace *sr, ...)
+cb_edit_search_replace_query (GnmSearchReplaceQuery q, GnmSearchReplace *sr, ...)
 {
-	int res = 0;
+	int res;
 	va_list pvar;
 	WorkbookControlGUI *wbcg = sr->user_data;
 
 	va_start (pvar, sr);
 
 	switch (q) {
-	case SRQ_fail: {
+	case GNM_SRQ_FAIL: {
 		GnmCell *cell = va_arg (pvar, GnmCell *);
-		char const *old_text = va_arg (pvar, const char *);
-		char const *new_text = va_arg (pvar, const char *);
-
-		char *err;
-
-		err = g_strdup_printf
+		char const *old_text = va_arg (pvar, char const *);
+		char const *new_text = va_arg (pvar, char const *);
+		char *err = g_strdup_printf
 			(_("In cell %s, the current contents\n"
 			   "        %s\n"
 			   "would have been replaced by\n"
@@ -406,13 +411,14 @@ cb_edit_search_replace_query (SearchReplaceQuery q, GnmSearchReplace *sr, ...)
 
 		go_gtk_notice_dialog (wbcg_toplevel (wbcg), GTK_MESSAGE_ERROR, err);
 		g_free (err);
+		res = GTK_RESPONSE_NO;
 		break;
 	}
 
-	case SRQ_query: {
+	case GNM_SRQ_QUERY: {
 		GnmCell *cell = va_arg (pvar, GnmCell *);
-		char const *old_text = va_arg (pvar, const char *);
-		char const *new_text = va_arg (pvar, const char *);
+		char const *old_text = va_arg (pvar, char const *);
+		char const *new_text = va_arg (pvar, char const *);
 		Sheet *sheet = cell->base.sheet;
 		char *pos_name = g_strconcat (sheet->name_unquoted, "!",
 					      cell_name (cell), NULL);
@@ -425,11 +431,11 @@ cb_edit_search_replace_query (SearchReplaceQuery q, GnmSearchReplace *sr, ...)
 		break;
 	}
 
-	case SRQ_querycommment: {
+	case GNM_SRQ_QUERY_COMMENT: {
 		Sheet *sheet = va_arg (pvar, Sheet *);
 		GnmCellPos *cp = va_arg (pvar, GnmCellPos *);
-		const char *old_text = va_arg (pvar, const char *);
-		const char *new_text = va_arg (pvar, const char *);
+		char const *old_text = va_arg (pvar, char const *);
+		char const *new_text = va_arg (pvar, char const *);
 		char *pos_name = g_strdup_printf (_("Comment in cell %s!%s"),
 						  sheet->name_unquoted,
 						  cellpos_as_string (cp));
@@ -441,6 +447,9 @@ cb_edit_search_replace_query (SearchReplaceQuery q, GnmSearchReplace *sr, ...)
 		break;
 	}
 
+	default:
+		/* Shouldn't really happen.  */
+		res = GTK_RESPONSE_CANCEL;
 	}
 
 	va_end (pvar);
@@ -475,13 +484,13 @@ static GNM_ACTION_DEF (cb_edit_fill_autofill)
 		gboolean do_loop;
 		GSList *merges, *ptr;
 
-		if (range_trim (sheet, &src, TRUE, TRUE))
+		if (sheet_range_trim (sheet, &src, TRUE, TRUE))
 			return; /* Region totally empty */
 
 		/* trim is a bit overzealous, it forgets about merges */
 		do {
 			do_loop = FALSE;
-			merges = sheet_merge_get_overlap (sheet, &src);
+			merges = gnm_sheet_merge_get_overlap (sheet, &src);
 			for (ptr = merges ; ptr != NULL ; ptr = ptr->next) {
 				GnmRange const *r = ptr->data;
 				if (src.end.col < r->end.col) {
@@ -529,7 +538,7 @@ static GNM_ACTION_DEF (cb_edit_recalc)
 	 * ctrl-alt-f9 -  force a full recalc across all sheets
 	 * ctrl-alt-shift-f9  -  a full-monty super recalc
 	 */
-	workbook_recalc_all (wb_control_workbook (WORKBOOK_CONTROL (wbcg)));
+	workbook_recalc_all (wb_control_get_workbook (WORKBOOK_CONTROL (wbcg)));
 }
 
 static GNM_ACTION_DEF (cb_repeat)	{ command_repeat (WORKBOOK_CONTROL (wbcg)); }
@@ -568,20 +577,10 @@ static GNM_ACTION_DEF (cb_view_zoom_out)
 
 static GNM_ACTION_DEF (cb_view_fullscreen)
 {
-#ifdef USE_HILDON
-	if (wbcg->is_fullscreen || hildon_appview_get_fullscreen (HILDON_APPVIEW (wbcg->toplevel))) {
-		wbcg->is_fullscreen = FALSE;
-		hildon_appview_set_fullscreen (HILDON_APPVIEW (wbcg->toplevel), FALSE);
-	} else {
-		wbcg->is_fullscreen = TRUE;
-		hildon_appview_set_fullscreen (HILDON_APPVIEW (wbcg->toplevel), TRUE);
-	}
-#else
 	if (wbcg->is_fullscreen)
 		gtk_window_unfullscreen (wbcg_toplevel (wbcg));
 	else
 		gtk_window_fullscreen (wbcg_toplevel (wbcg));
-#endif
 }
 
 static GNM_ACTION_DEF (cb_view_zoom)	{ dialog_zoom (wbcg, wbcg_cur_sheet (wbcg)); }
@@ -592,7 +591,7 @@ static GNM_ACTION_DEF (cb_view_freeze_panes)
 	SheetView *sv = wb_control_cur_sheet_view (wbc);
 	SheetControlGUI *scg = wbcg_cur_scg (wbcg);
 
-	scg_mode_edit (SHEET_CONTROL (scg));
+	scg_mode_edit (scg);
 	if (scg->active_panes == 1) {
 		gboolean center = FALSE;
 		GnmCanvas const *gcanvas = scg_pane (scg, 0);
@@ -635,7 +634,7 @@ static GNM_ACTION_DEF (cb_view_freeze_panes)
 static GNM_ACTION_DEF (cb_insert_current_date_time)
 {
 	if (wbcg_edit_start (wbcg, FALSE, FALSE)) {
-		Workbook const *wb = wb_control_workbook (WORKBOOK_CONTROL (wbcg));
+		Workbook const *wb = wb_control_get_workbook (WORKBOOK_CONTROL (wbcg));
 		GnmValue *v = value_new_float (
 			datetime_timet_to_serial_raw (time (NULL), workbook_date_conv (wb)));
 		char *txt = format_value (go_format_default_date_time (), v, NULL, -1,
@@ -648,7 +647,7 @@ static GNM_ACTION_DEF (cb_insert_current_date_time)
 static GNM_ACTION_DEF (cb_insert_current_date)
 {
 	if (wbcg_edit_start (wbcg, FALSE, FALSE)) {
-		Workbook const *wb = wb_control_workbook (WORKBOOK_CONTROL (wbcg));
+		Workbook const *wb = wb_control_get_workbook (WORKBOOK_CONTROL (wbcg));
 		GnmValue *v = value_new_int (
 			datetime_timet_to_serial (time (NULL), workbook_date_conv (wb)));
 		char *txt = format_value (go_format_default_date (), v, NULL, -1,
@@ -662,7 +661,7 @@ static GNM_ACTION_DEF (cb_insert_current_date)
 static GNM_ACTION_DEF (cb_insert_current_time)
 {
 	if (wbcg_edit_start (wbcg, FALSE, FALSE)) {
-		Workbook const *wb = wb_control_workbook (WORKBOOK_CONTROL (wbcg));
+		Workbook const *wb = wb_control_get_workbook (WORKBOOK_CONTROL (wbcg));
 		GnmValue *v = value_new_float (
 			datetime_timet_to_seconds (time (NULL)) / (24.0 * 60 * 60));
 		char *txt = format_value (go_format_default_time (), v, NULL, -1,
@@ -796,7 +795,7 @@ static GNM_ACTION_DEF (cb_auto_filter)
 		 * filter the region below this row. */
 		region = *src;
 		if (src->start.row == src->end.row)
-			sheet_filter_guess_region  (sv->sheet, &region);
+			gnm_sheet_filter_guess_region  (sv->sheet, &region);
 		if (region.start.row == region.end.row) {
 			go_cmd_context_error_invalid	(GO_CMD_CONTEXT (wbcg),
 				 _("AutoFilter"), _("Requires more than 1 row"));
@@ -808,7 +807,7 @@ static GNM_ACTION_DEF (cb_auto_filter)
 		gnm_filter_remove (filter);
 		gnm_filter_free (filter);
 	}
-	sheet_set_dirty (sv->sheet, TRUE);
+	sheet_mark_dirty (sv->sheet);
 	sheet_update (sv->sheet);
 }
 
@@ -817,9 +816,8 @@ static GNM_ACTION_DEF (cb_data_filter)		{ dialog_advanced_filter (wbcg); }
 static GNM_ACTION_DEF (cb_data_validate)	{ dialog_cell_format (wbcg, FD_VALIDATION); }
 static GNM_ACTION_DEF (cb_data_text_to_columns) { stf_text_to_columns (WORKBOOK_CONTROL (wbcg), GO_CMD_CONTEXT (wbcg)); }
 static GNM_ACTION_DEF (cb_data_consolidate)	{ dialog_consolidate (wbcg); }
-
-#ifdef ENABLE_PIVOTS
-static GNM_ACTION_DEF (cb_data_pivottable)	{ dialog_pivottable (wbcg); }
+#ifdef DATA_SLICER
+static GNM_ACTION_DEF (cb_data_slicer)		{ dialog_data_slicer (wbcg); }
 #endif
 
 static void
@@ -907,24 +905,25 @@ static GNM_ACTION_DEF (cb_help_docs)
 	char   *argv[] = { NULL, NULL, NULL };
 	GError *error = NULL;
 
-#warning "handle translations when we generate them"
 #ifndef G_OS_WIN32
 	argv[0] = (char *)"yelp";
-	argv[1] = g_build_filename (gnm_sys_data_dir (), "doc", "C",
-			"gnumeric.xml", NULL);
+	argv[1] = (char *)"help:gnumeric";
+	g_spawn_async (NULL, argv, NULL, G_SPAWN_SEARCH_PATH,
+		NULL, NULL, NULL, &error);
 #else
+	/* TODO : handle translations when we generate them */
 	argv[0] = (char *)"hh";
 	argv[1] = g_build_filename (gnm_sys_data_dir (), "doc", "C",
 			"gnumeric.chm", NULL);
-#endif
 	g_spawn_async (NULL, argv, NULL, G_SPAWN_SEARCH_PATH,
 		NULL, NULL, NULL, &error);
 	g_free (argv[1]);
+#endif
 }
 
 static GNM_ACTION_DEF (cb_help_web)
 {
-	GError *err = go_url_show ("http://www.gnome.org/projects/gnumeric/");
+	GError *err = go_url_show ("http://www.gnumeric.org/");
 	if (err != NULL) {
 		go_cmd_context_error (GO_CMD_CONTEXT (wbcg), err);
 		g_error_free (err);
@@ -1023,6 +1022,12 @@ sort_by_rows (WorkbookControlGUI *wbcg, gboolean descending)
 	sel = range_dup (tmp);
 	range_clip_to_finite (sel, sv_sheet (sv));
 
+	if (gnm_app_prefs->sort_default_has_header) {
+		sel->start.row++;
+		if (sel->start.row > sel->end.row)
+			return;
+	}
+
 	numclause = range_width (sel);
 	clause = g_new0 (GnmSortClause, numclause);
 	for (i=0; i < numclause; i++) {
@@ -1048,7 +1053,7 @@ sort_by_rows (WorkbookControlGUI *wbcg, gboolean descending)
 	 */
 	data->top = TRUE;
 
-	if (range_has_header (data->sheet, data->range, data->top, FALSE))
+	if (sheet_range_has_heading (data->sheet, data->range, data->top, FALSE))
 		data->range->start.row += 1;
 
 	cmd_sort (WORKBOOK_CONTROL (wbcg), data);
@@ -1077,7 +1082,7 @@ create_object (WorkbookControlGUI *wbcg, GType t,
 	       ...)
 {
 	SheetControlGUI *scg = wbcg_cur_scg (wbcg);
-	Sheet *sheet = sc_sheet (SHEET_CONTROL (scg));
+	Sheet *sheet = scg_sheet (scg);
 	va_list	args;
 
 	va_start (args, first_property_name);
@@ -1262,7 +1267,7 @@ toggle_font_attr (WorkbookControlGUI *wbcg, GtkToggleAction *act,
 	case MSTYLE_FONT_UNDERLINE:	gnm_style_set_font_uline (new_style, val); break;
 	case MSTYLE_FONT_STRIKETHROUGH: gnm_style_set_font_strike (new_style, val); break;
 	case MSTYLE_FONT_SCRIPT:	gnm_style_set_font_script (new_style, val); break;
-	};
+	}
 
 	cmd_selection_format (wbc, new_style, NULL, _("Set Font Style"));
 }
@@ -1342,14 +1347,14 @@ static GNM_ACTION_DEF (cb_format_as_date)
 static void
 mutate_borders (WorkbookControlGUI *wbcg, gboolean add)
 {
-	GnmBorder *borders [STYLE_BORDER_EDGE_MAX];
+	GnmBorder *borders [GNM_STYLE_BORDER_EDGE_MAX];
 	int i;
 
-	for (i = STYLE_BORDER_TOP; i < STYLE_BORDER_EDGE_MAX; ++i)
-		if (i <= STYLE_BORDER_RIGHT)
-			borders[i] = style_border_fetch (
-				add ? STYLE_BORDER_THIN : STYLE_BORDER_NONE,
-				style_color_black (), style_border_get_orientation (i));
+	for (i = GNM_STYLE_BORDER_TOP; i < GNM_STYLE_BORDER_EDGE_MAX; ++i)
+		if (i <= GNM_STYLE_BORDER_RIGHT)
+			borders[i] = gnm_style_border_fetch (
+				add ? GNM_STYLE_BORDER_THIN : GNM_STYLE_BORDER_NONE,
+				style_color_black (), gnm_style_border_get_orientation (i));
 		else
 			borders[i] = NULL;
 
@@ -1389,47 +1394,8 @@ static GNM_ACTION_DEF (cb_format_dec_precision)
 static GNM_ACTION_DEF (cb_format_with_thousands)
 	{ modify_format (wbcg, &go_format_toggle_1000sep, _("Toggle thousands separator")); }
 
-static GNM_ACTION_DEF (cb_format_inc_indent)
-{
-	WorkbookControl *wbc = WORKBOOK_CONTROL (wbcg);
-	WorkbookView const *wbv;
-	int i;
-
-	wbv = wb_control_view (wbc);
-	g_return_if_fail (wbv != NULL);
-	g_return_if_fail (wbv->current_format != NULL);
-
-	i = gnm_style_get_indent (wbv->current_format);
-	if (i < 20) {
-		GnmStyle *style = gnm_style_new ();
-
-		if (HALIGN_LEFT != gnm_style_get_align_h (wbv->current_format))
-			gnm_style_set_align_h (style, HALIGN_LEFT);
-		gnm_style_set_indent (style, i+1);
-		cmd_selection_format (wbc, style, NULL,
-			    _("Increase Indent"));
-	}
-}
-
-static GNM_ACTION_DEF (cb_format_dec_indent)
-{
-	WorkbookControl *wbc = WORKBOOK_CONTROL (wbcg);
-	WorkbookView const *wbv;
-	int i;
-
-	wbv = wb_control_view (wbc);
-	g_return_if_fail (wbv != NULL);
-	g_return_if_fail (wbv->current_format != NULL);
-
-	i = gnm_style_get_indent (wbv->current_format);
-	if (i > 0) {
-		GnmStyle *style = gnm_style_new ();
-
-		gnm_style_set_indent (style, i-1);
-		cmd_selection_format (wbc, style, NULL,
-			    _("Decrease Indent"));
-	}
-}
+static GNM_ACTION_DEF (cb_format_dec_indent) { workbook_cmd_dec_indent (WORKBOOK_CONTROL (wbcg)); }
+static GNM_ACTION_DEF (cb_format_inc_indent) { workbook_cmd_inc_indent (WORKBOOK_CONTROL (wbcg)); }
 
 static GNM_ACTION_DEF (cb_copydown)
 {
@@ -1492,6 +1458,7 @@ static GNM_ACTION_DEF (cb_format_row_unhide)
 /* Actions that are always sensitive */
 static GtkActionEntry const permanent_actions[] = {
 	{ "MenuFile",		NULL, N_("_File") },
+		{ "FilePrintArea",      NULL, N_("Print Area")},
 	{ "MenuEdit",		NULL, N_("_Edit") },
 		{ "MenuEditClear",	GTK_STOCK_CLEAR, N_("C_lear") },
 		{ "MenuEditDelete",	GTK_STOCK_DELETE, N_("_Delete") },
@@ -1520,6 +1487,12 @@ static GtkActionEntry const permanent_actions[] = {
 		{ "MenuExternalData",	NULL,	N_("Get _External Data") },
 	{ "MenuHelp",	NULL,	N_("_Help") },
 
+	{ "FileSave", GTK_STOCK_SAVE, NULL,
+		NULL, N_("Save the current workbook"),
+		G_CALLBACK (cb_file_save) },
+	{ "FileSaveAs", GTK_STOCK_SAVE_AS, NULL,
+		"<control><shift>s", N_("Save the current workbook with a different name"),
+		G_CALLBACK (cb_file_save_as) },
 	{ "FileClose", GTK_STOCK_CLOSE, NULL,
 		NULL, N_("Close the current file"),
 		G_CALLBACK (cb_file_close) },
@@ -1536,14 +1509,12 @@ static GtkActionEntry const permanent_actions[] = {
 	{ "EditPaste", GTK_STOCK_PASTE, NULL,
 		NULL, N_("Paste the clipboard"),
 		G_CALLBACK (cb_edit_paste) },
-#ifdef USE_HILDON
-	{ "UndoHildon", GTK_STOCK_UNDO, N_("_Undo"), 
+	{ "UndoLast", GTK_STOCK_UNDO, N_("_Undo"), 
 		NULL, N_("Undo the last action"), 
-		G_CALLBACK (cb_edit_undo) },
-	{ "RedoHildon", GTK_STOCK_REDO, N_("_Redo"),
+		G_CALLBACK (cb_edit_undo_last) },
+	{ "RedoLast", GTK_STOCK_REDO, N_("_Redo"),
 		NULL, N_("Redo the undone action"), 
-		G_CALLBACK (cb_edit_redo) },
-#endif		
+		G_CALLBACK (cb_edit_redo_last) },
 
 	{ "HelpDocs", GTK_STOCK_HELP, N_("_Contents"),
 		"F1", N_("Open a viewer for Gnumeric's documentation"),
@@ -1568,6 +1539,16 @@ static GtkActionEntry const permanent_actions[] = {
 		G_CALLBACK (cb_repeat) }
 };
 
+#ifdef USE_HILDON
+#define FULLSCREEN_ACCEL "F6"
+#define ZOOM_IN_ACCEL "F7"
+#define ZOOM_OUT_ACCEL "F8"
+#else
+#define FULLSCREEN_ACCEL "F11"
+#define ZOOM_IN_ACCEL NULL
+#define ZOOM_OUT_ACCEL NULL
+#endif
+
 static GtkActionEntry const actions[] = {
 /* File */
 	{ "FileNew", GTK_STOCK_NEW, NULL,
@@ -1576,12 +1557,6 @@ static GtkActionEntry const actions[] = {
 	{ "FileOpen", GTK_STOCK_OPEN, NULL,
 		NULL, N_("Open a file"),
 		G_CALLBACK (cb_file_open) },
-	{ "FileSave", GTK_STOCK_SAVE, NULL,
-		NULL, N_("Save the current workbook"),
-		G_CALLBACK (cb_file_save) },
-	{ "FileSaveAs", GTK_STOCK_SAVE_AS, NULL,
-		"<control><shift>s", N_("Save the current workbook with a different name"),
-		G_CALLBACK (cb_file_save_as) },
 	{ "FileSend", "Gnumeric_Link_EMail", N_("Sen_d To..."),
 		NULL, N_("Send the current file via email"),
 		G_CALLBACK (cb_file_sendto) },
@@ -1594,17 +1569,23 @@ static GtkActionEntry const actions[] = {
 	{ "FilePrint", GTK_STOCK_PRINT, NULL,
 		"<control>p", N_("Print the current file"),
 		G_CALLBACK (cb_file_print) },
-	{ "FileSummary", GTK_STOCK_PROPERTIES, N_("Proper_ties..."),
+	{ "FileMetaData", GTK_STOCK_PROPERTIES, N_("Proper_ties..."),
 		NULL, N_("Edit descriptive information"),
-		G_CALLBACK (cb_file_summary) },
+		G_CALLBACK (cb_doc_meta_data) },
 	{ "FilePreferences", GTK_STOCK_PREFERENCES, N_("Pre_ferences..."),
 		NULL, N_("Change Gnumeric Preferences"),
 		G_CALLBACK (cb_file_preferences) },
 
-/* new hook put here to avoid patch conflict */
-	{ "FileSummary_new", GTK_STOCK_PROPERTIES, N_("NEW Proper_ties..."),
-		NULL, N_("Edit descriptive information"),
-		G_CALLBACK (cb_new_doc_metadata) },
+/* File->PrintArea */
+        { "FilePrintAreaSet", NULL, N_("Set Print Area"),
+                NULL, N_("Use the current selection as print area"),
+                G_CALLBACK (cb_file_print_area_set)},
+        { "FilePrintAreaClear", NULL, N_("Clear Print Area"),
+                NULL, N_("Undefine the print area"),
+                G_CALLBACK (cb_file_print_area_clear)},
+        { "FilePrintAreaShow", NULL, N_("Show Print Area"),
+                NULL, N_("Select the print area"),
+                G_CALLBACK (cb_file_print_area_show)},
 
 /* Edit -> Clear */
 	{ "EditClearAll", NULL, N_("_All"),
@@ -1633,15 +1614,26 @@ static GtkActionEntry const actions[] = {
 
 
 /* Edit -> Select */
+
+	/* Note : The accelerators involving space are just for display
+	 * 	purposes.  We actually handle this in
+	 * 		gnumeric-canvas.c:gnm_canvas_key_mode_sheet
+	 *	with the rest of the key movement and rangeselection.
+	 *	Otherwise input methods would steal them */
 	{ "EditSelectAll", NULL, N_("Select _All"),
+		"<control><shift>space", N_("Select all cells in the spreadsheet"),
+		G_CALLBACK (cb_edit_select_all) },
+	/* A duplicate that should not go into the menus, used only for the accelerator */
+	{ "EditSelectAllXL", NULL, N_("Select _All"),
 		"<control>a", N_("Select all cells in the spreadsheet"),
 		G_CALLBACK (cb_edit_select_all) },
 	{ "EditSelectColumn", NULL, N_("Select _Column"),
 		"<control>space", N_("Select an entire column"),
 		G_CALLBACK (cb_edit_select_col) },
 	{ "EditSelectRow", NULL, N_("Select _Row"),
-		"<alt>space", N_("Select an entire row"),
+		"<shift>space", N_("Select an entire row"),
 		G_CALLBACK (cb_edit_select_row) },
+
 	{ "EditSelectArray", NULL, N_("Select Arra_y"),
 		"<control>slash", N_("Select an array of cells"),
 		G_CALLBACK (cb_edit_select_array) },
@@ -1651,9 +1643,6 @@ static GtkActionEntry const actions[] = {
 	{ "EditSelectInputs", NULL, N_("Select _Inputs"),
 		"<control>bracketleft", N_("Select all the cells are used by the current edit cell"),
 		G_CALLBACK (cb_edit_select_inputs) },
-	{ "EditMetadata", NULL, N_("Edit Metadata"),
-		NULL, N_("Edit the document's extra information (metadata)"),
-		G_CALLBACK (cb_new_doc_metadata) },
 
 /* Edit -> Fill */
 	{ "EditFillAutofill", NULL, N_("Auto_fill"),
@@ -1688,7 +1677,7 @@ static GtkActionEntry const actions[] = {
 		G_CALLBACK (wbcg_append_sheet) },
 	{ "EditDuplicateSheet", NULL, N_("_Duplicate"),
 		NULL, N_("Make a copy of the current sheet"),
-		G_CALLBACK (cb_edit_duplicate_sheet) },
+		G_CALLBACK (wbcg_clone_sheet) },
 	{ "SheetRemove", NULL, N_("_Remove"),
 		NULL, N_("Irrevocably remove an entire sheet"),
 		G_CALLBACK (cb_sheet_remove) },
@@ -1730,10 +1719,10 @@ static GtkActionEntry const actions[] = {
 		NULL, N_("Zoom the spreadsheet in or out"),
 		G_CALLBACK (cb_view_zoom) },
 	{ "ViewZoomIn", GTK_STOCK_ZOOM_IN, N_("Zoom _In"),
-		NULL, N_("Increase the zoom to make things larger"),
+		ZOOM_IN_ACCEL, N_("Increase the zoom to make things larger"),
 		G_CALLBACK (cb_view_zoom_in) },
 	{ "ViewZoomOut", GTK_STOCK_ZOOM_OUT, N_("Zoom _Out"),
-		NULL, N_("Decrease the zoom to make things smaller"),
+		ZOOM_OUT_ACCEL, N_("Decrease the zoom to make things smaller"),
 		G_CALLBACK (cb_view_zoom_out) },
 	{ "Direction", GTK_STOCK_GO_FORWARD, N_("Direction"),
 		NULL, N_("Toggle sheet direction, left to right vs right to left"),
@@ -1941,11 +1930,10 @@ static GtkActionEntry const actions[] = {
 	{ "DataConsolidate", NULL, N_("_Consolidate..."),
 		NULL, N_("Consolidate regions using a function"),
 		G_CALLBACK (cb_data_consolidate) },
-
-#ifdef ENABLE_PIVOTS
-	{ "PivotTable", "Gnumeric_PivotTable", N_("_PivotTable..."),
-		NULL, N_("Create a pivot table"),
-		G_CALLBACK (cb_data_pivottable) },
+#ifdef DATA_SLICER
+	{ "DataSlice", "Gnumeric_DataSlice", N_("_Data Slice..."),
+		NULL, N_("Create a Data Slice"),
+		G_CALLBACK (cb_data_slicer) },
 #endif
 
 /* Data -> Outline */
@@ -1956,10 +1944,10 @@ static GtkActionEntry const actions[] = {
 		NULL, N_("Uncollapse an outline group"),
 		G_CALLBACK (cb_data_show_detail) },
 	{ "DataOutlineGroup", "Gnumeric_Group", N_("_Group..."),
-		NULL, N_("Add an outline group"),
+		"<shift><alt>Right", N_("Add an outline group"),
 		G_CALLBACK (cb_data_group) },
 	{ "DataOutlineUngroup", "Gnumeric_Ungroup", N_("_Ungroup..."),
-		NULL, N_("Remove an outline group"),
+		"<shift><alt>Left", N_("Remove an outline group"),
 		G_CALLBACK (cb_data_ungroup) },
 
 /* Data -> Filter */
@@ -1979,7 +1967,7 @@ static GtkActionEntry const actions[] = {
 
 /* Standard Toolbar */
 	{ "AutoSum", "Gnumeric_AutoSum", N_("Sum"),
-		NULL, N_("Sum into the current cell"),
+		"<alt>equal", N_("Sum into the current cell"),
 		G_CALLBACK (cb_autosum) },
 	{ "InsertFormula", "Gnumeric_FormulaGuru", N_("Function"), NULL,
 		N_("Edit a function in the current cell"),
@@ -2069,7 +2057,7 @@ static GtkActionEntry const actions[] = {
 		"<control>at", N_("Format the selection as time"),
 		G_CALLBACK (cb_format_as_time) },
 	{ "FormatAddBorders", NULL, N_("AddBorders"),
-		"<control>ampersand", N_("Add a border the the selection"),
+		"<control>ampersand", N_("Add a border around the selection"),
 		G_CALLBACK (cb_format_add_borders) },
 	{ "FormatClearBorders", NULL, N_("ClearBorders"),
 		"<control>underscore", N_("Clear the border around the selection"),
@@ -2084,11 +2072,14 @@ static GtkActionEntry const actions[] = {
 	{ "FormatDecreasePrecision", "Gnumeric_FormatRemovePrecision", N_("Decrease Precision"),
 		NULL, N_("Decrease the number of decimals displayed"),
 		G_CALLBACK (cb_format_dec_precision) },
+
+	/* Gtk marks these accelerators as invalid because they use Tab
+	 * enable them manually in gnumeric-canvas.c */
 	{ "FormatDecreaseIndent", GTK_STOCK_UNINDENT, NULL,
-		NULL, N_("Decrease the indent, and align the contents to the left"),
+		"<control><alt><shift>Tab", N_("Decrease the indent, and align the contents to the left"),
 		G_CALLBACK (cb_format_dec_indent) },
 	{ "FormatIncreaseIndent", GTK_STOCK_INDENT, NULL,
-		NULL, N_("Increase the indent, and align the contents to the left"),
+		"<control><alt>Tab", N_("Increase the indent, and align the contents to the left"),
 		G_CALLBACK (cb_format_inc_indent) },
 /* Unattached */
 #warning add descriptions for copy down/right
@@ -2184,8 +2175,9 @@ static GtkToggleActionEntry const toggle_actions[] = {
 	        G_CALLBACK (cb_view_statusbar), TRUE },
 
 	{ "ViewFullScreen", GTK_STOCK_ZOOM_FIT,
-		N_("F_ull Screen"), "F11",
-		N_("in or out"), G_CALLBACK (cb_view_fullscreen), FALSE }
+		N_("F_ull Screen"), FULLSCREEN_ACCEL,
+		N_("Switch to or from full screen mode"),
+		G_CALLBACK (cb_view_fullscreen), FALSE }
 };
 
 static GtkToggleActionEntry const font_toggle_actions[] = {
