@@ -695,7 +695,7 @@ gee_prepare_range (GnmExprEntry const *gee, GnmRangeRef *dst)
 
 		corner.col = MIN (dst->a.col, dst->b.col);
 		corner.row = MIN (dst->a.row, dst->b.row);
-		merge = sheet_merge_is_corner (gee->sheet, &corner);
+		merge = gnm_sheet_merge_is_corner (gee->sheet, &corner);
 		if (merge != NULL &&
 		    merge->end.col == MAX (dst->a.col, dst->b.col) &&
 		    merge->end.row == MAX (dst->a.row, dst->b.row)) {
@@ -1102,7 +1102,7 @@ gnm_expr_entry_set_scg (GnmExprEntry *gee, SheetControlGUI *scg)
 				   (GWeakNotify) cb_scg_destroy, gee);
 		gee->sheet = sc_sheet (SHEET_CONTROL (scg));
 		parse_pos_init_sheet (&gee->pp, gee->sheet);
-		gee->wbcg = scg_get_wbcg (gee->scg);
+		gee->wbcg = scg_wbcg (gee->scg);
 	} else
 		gee->sheet = NULL;
 #if 0
