@@ -122,9 +122,9 @@ wbcg_edit_finish (WorkbookControlGUI *wbcg, WBCEditResult result,
 		char const *txt = wbcg_edit_get_display_text (wbcg);
 		GnmStyle const *mstyle = sheet_style_get (sheet, sv->edit_pos.col, sv->edit_pos.row);
 		char const *expr_txt = NULL;
+		GOFormat *fmt = gnm_cell_get_format (sheet_cell_fetch (sheet, sv->edit_pos.col, sv->edit_pos.row));
 
-		/* BE CAREFUL the standard fmts must not NOT include '@' */
-		GnmValue *value = format_match (txt, gnm_style_get_format (mstyle),
+		GnmValue *value = format_match (txt, fmt,
 						workbook_date_conv (sheet->workbook));
 		if (value != NULL)
 			value_release (value);
@@ -215,8 +215,7 @@ wbcg_edit_finish (WorkbookControlGUI *wbcg, WBCEditResult result,
 
 		valid = validation_eval (wbc, mstyle, sheet, &sv->edit_pos, showed_dialog);
 
-		if (free_txt != NULL)
-			g_free (free_txt);
+		g_free (free_txt);
 
 		if (valid != VALIDATION_STATUS_VALID) {
 			result = WBC_EDIT_REJECT;
@@ -285,11 +284,14 @@ wbcg_edit_finish (WorkbookControlGUI *wbcg, WBCEditResult result,
 
 	wb_control_update_action_sensitivity (wbc);
 
-	/* restore focus to original sheet in case things were being selected
-	 * on a different page.  Do no go through the view, rangesel is
-	 * specific to the control.  */
-	wb_control_sheet_focus (wbc, sheet);
-	scg_edit_stop (wbcg_cur_scg (wbcg));	/* Only the edit sheet has an edit cursor */
+	if (!sheet->workbook->during_destruction) {
+		/* restore focus to original sheet in case things were being selected
+		 * on a different page.  Do no go through the view, rangesel is
+		 * specific to the control.  */
+		wb_control_sheet_focus (wbc, sheet);
+		/* Only the edit sheet has an edit cursor */
+		scg_edit_stop (wbcg_cur_scg (wbcg));
+	}
 	wbcg_auto_complete_destroy (wbcg);
 	wb_control_style_feedback (wbc, NULL);	/* in case markup messed with things */
 
@@ -566,10 +568,12 @@ cb_entry_delete_text (GtkEditable    *editable,
 		      WorkbookControlGUI *wbcg)
 {
 	if (wbcg->auto_completing) {
+		SheetControlGUI *scg = wbcg_cur_scg (wbcg);
 		wbcg_auto_complete_destroy (wbcg);
-		SCG_FOREACH_PANE (wbcg_cur_scg (wbcg), pane,
-			if (pane->editor != NULL)
-				foo_canvas_item_request_update (FOO_CANVAS_ITEM (pane->editor)););
+		if (scg)
+			SCG_FOREACH_PANE (scg, pane,
+					  if (pane->editor != NULL)
+					  foo_canvas_item_request_update (FOO_CANVAS_ITEM (pane->editor)););
 	}
 
 	if (wbcg->edit_line.full_content) {
@@ -766,8 +770,8 @@ wbcg_edit_start (WorkbookControlGUI *wbcg,
 	cell = sheet_cell_get (sv->sheet, col, row);
 	if (cell &&
 	    warn_on_text_format &&
-	    go_format_is_text (cell_get_format (cell)) &&
-	    (cell_has_expr (cell) || !VALUE_IS_STRING (cell->value))) {
+	    go_format_is_text (gnm_cell_get_format (cell)) &&
+	    (gnm_cell_has_expr (cell) || !VALUE_IS_STRING (cell->value))) {
 		GtkResponseType res;
 		GtkWidget *check;
 		GtkWidget *align;
@@ -821,19 +825,19 @@ wbcg_edit_start (WorkbookControlGUI *wbcg,
 	else if (cell != NULL) {
 		gboolean set_text = FALSE;
 
-		if (cell_is_array (cell)) {
+		if (gnm_cell_is_array (cell)) {
 			/* If this is part of an array we need to remove the
 			 * '{' '}' and the size information from the display.
 			 * That is not actually part of the parsable expression.
 			 */
 			set_text = TRUE;
-		} else if (!cell_has_expr (cell) && VALUE_IS_FLOAT (cell->value)) {
-			GOFormat *fmt = cell_get_format (cell);
+		} else if (!gnm_cell_has_expr (cell) && VALUE_IS_FLOAT (cell->value)) {
+			GOFormat *fmt = gnm_cell_get_format (cell);
 			gnm_float f = value_get_as_float (cell->value);
 
 			switch (fmt->family) {
 			case GO_FORMAT_FRACTION:
-				text = cell_get_entered_text (cell);
+				text = gnm_cell_get_entered_text (cell);
 				g_strchug (text);
 				g_strchomp (text);
 				set_text = TRUE;
@@ -906,7 +910,7 @@ wbcg_edit_start (WorkbookControlGUI *wbcg,
 		}
 
 		if (!text)
-			text = cell_get_entered_text (cell);
+			text = gnm_cell_get_entered_text (cell);
 
 		if (set_text)
 			gtk_entry_set_text (wbcg_get_entry (wbcg), text);
